package com.javaproxy;

import android.app.Application;
import android.content.Context;
import android.content.ContextWrapper;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import java.lang.reflect.Field;
import java.lang.reflect.Method;

/* loaded from: com_javaproxy.jar:com/javaproxy/PluginManager.class */
public class PluginManager {
    public static final String TAG = "JAVAPROXY";
    private static Handler mHandler = null;
    private static Application mApp = null;
    private static Context mPluginContext = null;
    private static Class mPluginEntryClass = null;
    private static Object mPluginEntry = null;
    private static Method mStartScriptMethod = null;
    private static Method mCreateMethod = null;
    private static Method mStopScriptMethod = null;
    private static PlugInfo mInfo = null;

    public static native Bitmap takeCapture(int i, int i2, int i3, int i4);

    public static native void invokeLua(String str, String str2);

    public static native boolean invokeLuaWithBoolean(String str, String str2);

    public static native String invokeLuaWithString(String str, String str2);

    public static native int invokeLuaWithInt(String str, String str2);

    private static Application makeApplication(PlugInfo plugInfo, ApplicationInfo appInfo) {
        String appClassName = appInfo.className;
        if (appClassName == null) {
            appClassName = Application.class.getName();
        }
        try {
            return (Application) plugInfo.getClassLoader().loadClass(appClassName).newInstance();
        } catch (Throwable e) {
            throw new RuntimeException("Unable to create Application for " + plugInfo.getPackageName() + ": " + e.getMessage());
        }
    }

    private static void attachBaseContext(Context context, PlugInfo info, Application app) {
        try {
            Field mBase = ContextWrapper.class.getDeclaredField("mBase");
            mBase.setAccessible(true);
            mBase.set(app, new PluginContext(context.getApplicationContext(), info));
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void post(Runnable runnable) {
        if (mHandler != null && runnable != null) {
            mHandler.post(runnable);
        }
    }

    public static void postDelay(Runnable runnable, long delayMillis) {
        if (mHandler != null && runnable != null) {
            mHandler.postDelayed(runnable, delayMillis);
        }
    }

    public static String getApkPath() {
        if (mInfo != null) {
            return mInfo.getFilePath();
        }
        return "";
    }

    public static Application getApplication() {
        return (Application) mPluginContext;
    }

    public static void main(String apk, Application appctx, ClassLoader classLoader, Resources res) {
        try {
            mInfo = new PlugInfo();
            mInfo.setAssetManager(res.getAssets());
            mInfo.setResources(res);
            mInfo.setFilePath(apk);
            PluginManifestUtil.setManifestInfo(appctx, apk, mInfo);
            mInfo.setClassLoader(classLoader);
            ApplicationInfo appInfo = mInfo.getPackageInfo().applicationInfo;
            Application app = makeApplication(mInfo, appInfo);
            attachBaseContext(appctx, mInfo, app);
            mInfo.setApplication(app);
            mPluginContext = app;
            mPluginEntryClass = Class.forName("com.lr.plugin.main");
            mCreateMethod = mPluginEntryClass.getMethod("onCreate", Application.class);
            mStartScriptMethod = mPluginEntryClass.getMethod("onScriptStart", new Class[0]);
            mStopScriptMethod = mPluginEntryClass.getMethod("onScriptStop", new Class[0]);
            mApp = appctx;
            mHandler = new Handler(Looper.getMainLooper());
            mHandler.post(new Runnable() { // from class: com.javaproxy.PluginManager.1
                @Override // java.lang.Runnable
                public void run() {
                    try {
                        PluginManager.mPluginEntry = PluginManager.mPluginEntryClass.newInstance();
                        PluginManager.mCreateMethod.invoke(PluginManager.mPluginEntry, PluginManager.mPluginContext);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } catch (Exception e) {
        }
    }

    public static void onStart() {
        if (mHandler == null) {
            return;
        }
        try {
            mHandler.post(new Runnable() { // from class: com.javaproxy.PluginManager.2
                @Override // java.lang.Runnable
                public void run() {
                    try {
                        PluginManager.mStartScriptMethod.invoke(PluginManager.mPluginEntry, new Object[0]);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } catch (Exception e) {
        }
    }

    public static void onStop() {
        if (mHandler == null) {
            return;
        }
        try {
            mHandler.post(new Runnable() { // from class: com.javaproxy.PluginManager.3
                @Override // java.lang.Runnable
                public void run() {
                    try {
                        PluginManager.mStopScriptMethod.invoke(PluginManager.mPluginEntry, new Object[0]);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } catch (Exception e) {
        }
    }

    private static void runOrStopScript(boolean run) {
        try {
            Context ctx = mPluginContext;
            if (ctx == null) {
                return;
            }
            Class mainService = Class.forName("com.nx.main.service.MainService", true, ctx.getApplicationContext().getClassLoader());
            Intent it = new Intent(ctx, (Class<?>) mainService);
            if (run) {
                it.putExtra("action", "start");
            } else {
                it.putExtra("action", "stop");
            }
            ctx.startService(it);
        } catch (Exception e) {
            Log.i(TAG, e.toString());
        }
    }

    public static void startScript() {
        runOrStopScript(true);
    }

    public static void stopScript() {
        runOrStopScript(false);
    }
}
